﻿using System.Threading.Tasks;
using System.Threading;
using Telegram.Bot.Types.Enums; // Для ParseMode

namespace DailyDigestWorker.Services
{
    // Интерфейс для сервиса отправки сообщений через Telegram Bot API
    public interface ITelegramBotSender
    {
        /// <summary>
        /// Отправляет текстовое сообщение в указанный чат.
        /// </summary>
        /// <param name="messageText">Текст сообщения.</param>
        /// <param name="parseMode">Режим разметки (Markdown/Html).</param>
        /// <param name="cancellationToken">Токен отмены.</param>
        /// <returns>True, если отправка инициирована успешно, иначе false.</returns>
        Task<bool> SendMessageAsync(string messageText, ParseMode parseMode, CancellationToken cancellationToken);

        /// <summary>
        /// Отправляет сообщение об ошибке в целевой чат.
        /// </summary>
        /// <param name="errorMessage">Текст ошибки.</param>
        /// <param name="cancellationToken">Токен отмены.</param>
        /// <returns>True, если отправка инициирована успешно, иначе false.</returns>
        Task<bool> SendErrorMessageAsync(string errorMessage, CancellationToken cancellationToken);
    }
}